==> 1.0.0.tar.gz: android/src/main/java/com/bsdenterprise/flutter_mqtt_plugin/FlutterMqttPlugin.java <==
package com.bsdenterprise.flutter_mqtt_plugin;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import androidx.annotation.NonNull;
import com.amazonaws.services.iot.client.AWSIotException;
import com.amazonaws.services.iot.client.AWSIotMessage;
import com.amazonaws.services.iot.client.AWSIotQos;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.AWSIotMqttUtil;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.EventObject;
import com.google.gson.Gson;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.EventChannel.StreamHandler;
import io.flutter.plugin.common.EventChannel.EventSink;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** FlutterMqttBsdPlugin */
public class FlutterMqttPlugin implements FlutterPlugin, MethodCallHandler, StreamHandler, MqttCallback {

  private MethodChannel channel;
  private MqttClient mqttClient;
  private Result result;
  private Handler handler;
  private EventSink events;
  private Gson gson;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    flutterPluginBinding.getFlutterAssets();
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(),
            "mqtt.methods");
    channel.setMethodCallHandler(this);
    EventChannel eventChannel = new EventChannel(flutterPluginBinding.getBinaryMessenger(),
            "mqtt.events");
    eventChannel.setStreamHandler(this);
    this.gson = new Gson();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    this.result = result;
    handler = new Handler(Looper.getMainLooper());
    String topicName;
    switch (call.method) {
      case "connect":
        String certificate = call.argument("certificate");
        String privateKey = call.argument("privateKey");
        connect(certificate, privateKey);
        result.success("call success");
        break;
      case "disconnect":
        disconnect();
        result.success("call success");
        break;
      case "subscribe":
        topicName = call.argument("topicName");
        subscribe(topicName);
        result.success("call success");
        break;
      case "publish":
        topicName = call.argument("topicName");
        String payload = call.argument("payload");
        publish(topicName, payload);
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  private void connect(String certificate, String privateKey) {
    AWSIotMqttUtil.KeyStorePasswordPair pair = AWSIotMqttUtil.getKeyStorePasswordPair(certificate, privateKey);
    mqttClient = new MqttClient(pair, this);
    mqttClient.connectMqtt();
  }

  private void disconnect() {
    mqttClient.disconnectMqtt();
  }

  private void subscribe(String topicName) {
    if(mqttClient != null) {
      AWSIotQos qos = AWSIotQos.QOS0;
      MqttTopic topic = new MqttTopic(topicName, qos, this);
      try {
        mqttClient.unsubscribe(topic);
        mqttClient.subscribe(topic);
      } catch (AWSIotException e) {
        e.printStackTrace();
      }
    }
  }

  private void publish(String topicName, String payload) {
    if(mqttClient != null) {
      AWSIotQos qos = AWSIotQos.QOS0;
      long timeout = 3000;
      MqttMessage message = new MqttMessage(topicName, qos, payload, this);
      try {
        mqttClient.publish(message, timeout);
      } catch (AWSIotException e) {
        e.printStackTrace();
      }
    }
  }

  @Override
  public void onConnectionSuccess() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onConnectionSuccess";
        event.content = "connected";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onConnectionFailure() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onConnectionFailure";
        event.content = "connection error";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onConnectionClosed() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onConnectionClosed";
        event.content = "disconnected";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSubscribeSuccess() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onSubscribeSuccess";
        event.content = "subscribed";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSubscribeFailure() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onSubscribeFailure";
        event.content = "subscribe error";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSubscribeTimeout() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onSubscribeTimeout";
        event.content = "subscribe timeout";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSendSuccess() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        result.success("publish sent");
      }
    });
  }

  @Override
  public void onSendFailure() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        result.success("publish fail");
      }
    });
  }

  @Override
  public void onSendTimeout() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        result.success("publish timeout");
      }
    });
  }

  @Override
  public void onMessage(final AWSIotMessage message) {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onMessage";
        event.content = message.getStringPayload();
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onListen(Object arguments, EventSink events) {
    Log.d("EventChannel", "listening");
    this.events = events;
  }

  @Override
  public void onCancel(Object arguments) {
    Log.d("EventChannel", "cancelled");
    this.events = null;
  }
}

==> 1.0.1.tar.gz: android/src/main/java/com/bsdenterprise/flutter_mqtt_plugin/FlutterMqttPlugin.java <==
package com.bsdenterprise.flutter_mqtt_plugin;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import androidx.annotation.NonNull;
import com.amazonaws.services.iot.client.AWSIotException;
import com.amazonaws.services.iot.client.AWSIotMessage;
import com.amazonaws.services.iot.client.AWSIotQos;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.AWSIotMqttUtil;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.EventObject;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.MqttCallback;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.MqttClient;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.MqttMessage;
import com.bsdenterprise.flutter_mqtt_plugin.utilities.MqttTopic;
import com.google.gson.Gson;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.EventChannel.StreamHandler;
import io.flutter.plugin.common.EventChannel.EventSink;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** FlutterMqttBsdPlugin */
public class FlutterMqttPlugin implements FlutterPlugin, MethodCallHandler, StreamHandler, MqttCallback {

  private MethodChannel channel;
  private MqttClient mqttClient;
  private Result result;
  private Handler handler;
  private EventSink events;
  private Gson gson;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    flutterPluginBinding.getFlutterAssets();
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(),
            "mqtt.methods");
    channel.setMethodCallHandler(this);
    EventChannel eventChannel = new EventChannel(flutterPluginBinding.getBinaryMessenger(),
            "mqtt.events");
    eventChannel.setStreamHandler(this);
    this.gson = new Gson();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    this.result = result;
    handler = new Handler(Looper.getMainLooper());
    String topicName;
    switch (call.method) {
      case "connect":
        String clientEndpoint = call.argument("clientEndpoint");
        String certificate = call.argument("certificate");
        String privateKey = call.argument("privateKey");
        connect(clientEndpoint, certificate, privateKey);
        result.success("call success");
        break;
      case "disconnect":
        disconnect();
        result.success("call success");
        break;
      case "subscribe":
        topicName = call.argument("topicName");
        subscribe(topicName);
        result.success("call success");
        break;
      case "publish":
        topicName = call.argument("topicName");
        String payload = call.argument("payload");
        publish(topicName, payload);
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  private void connect(String clientEndpoint, String certificate, String privateKey) {
    AWSIotMqttUtil.KeyStorePasswordPair pair = AWSIotMqttUtil.getKeyStorePasswordPair(certificate, privateKey);
    mqttClient = new MqttClient(clientEndpoint, pair, this);
    mqttClient.connectMqtt();
  }

  private void disconnect() {
    mqttClient.disconnectMqtt();
  }

  private void subscribe(String topicName) {
    if(mqttClient != null) {
      AWSIotQos qos = AWSIotQos.QOS0;
      MqttTopic topic = new MqttTopic(topicName, qos, this);
      try {
        mqttClient.unsubscribe(topic);
        mqttClient.subscribe(topic);
      } catch (AWSIotException e) {
        e.printStackTrace();
      }
    }
  }

  private void publish(String topicName, String payload) {
    if(mqttClient != null) {
      AWSIotQos qos = AWSIotQos.QOS0;
      long timeout = 3000;
      MqttMessage message = new MqttMessage(topicName, qos, payload, this);
      try {
        mqttClient.publish(message, timeout);
      } catch (AWSIotException e) {
        e.printStackTrace();
      }
    }
  }

  @Override
  public void onConnectionSuccess() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onConnectionSuccess";
        event.content = "connected";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onConnectionFailure() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onConnectionFailure";
        event.content = "connection error";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onConnectionClosed() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onConnectionClosed";
        event.content = "disconnected";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSubscribeSuccess() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onSubscribeSuccess";
        event.content = "subscribed";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSubscribeFailure() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onSubscribeFailure";
        event.content = "subscribe error";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSubscribeTimeout() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onSubscribeTimeout";
        event.content = "subscribe timeout";
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onSendSuccess() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        result.success("publish sent");
      }
    });
  }

  @Override
  public void onSendFailure() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        result.success("publish fail");
      }
    });
  }

  @Override
  public void onSendTimeout() {
    handler.post(new Runnable() {
      @Override
      public void run() {
        result.success("publish timeout");
      }
    });
  }

  @Override
  public void onMessage(final AWSIotMessage message) {
    handler.post(new Runnable() {
      @Override
      public void run() {
        EventObject event = new EventObject();
        event.name = "onMessage";
        event.content = message.getStringPayload();
        events.success(gson.toJson(event));
      }
    });
  }

  @Override
  public void onListen(Object arguments, EventSink events) {
    Log.d("EventChannel", "listening");
    this.events = events;
  }

  @Override
  public void onCancel(Object arguments) {
    Log.d("EventChannel", "cancelled");
    this.events = null;
  }
}
